moving.average: calculate the moving average of a dataseries

Description Usage Arguments Value Author(s)

View source: R/analyse.R

Description

calculate the moving average of a dataseries

Usage

1
moving.average(x, n = 5)

Arguments

x

(vector). Vector containing the data that for which the average needs to be calculated.

n

(integer). Number of values for which the average needs to be calculated.

Value

vector. Data vector containing the averages. This vector is as long as the input (and thus contains NA's)

Author(s)

Pieter Coussement, coussementpieter@gmail.com


picousse/gRowthAnalysis documentation built on Nov. 14, 2019, 4:42 p.m.